@@ -1,5 +1,5 @@
 # -*- perl -*-
-# $Id: RobotPUA.pm,v 1.5 2001/07/26 09:26:23 langhein Exp $
+# $Id: RobotPUA.pm,v 1.1 1998/03/06 04:59:11 marc Exp $
 
 package LWP::RobotPUA;
 use Exporter();
@@ -19,13 +19,6 @@ __END__
 
 LWP::RobotPUA - Parallel LWP::RobotUA
 
-=head1 SYNOPSIS
-
-  require LWP::RobotPUA;
-  $ua = new LWP::RobotPUA 'my-robot/0.1', 'me@foo.com';
-
-  (see description of LWP::Parallel::RobotUA)
-
 =head1 DESCRIPTION
 
 RobotPUA is a simple frontend to the LWP::Parallel::RobotUA
@@ -42,18 +35,11 @@ module.
 
 =head1 AUTHOR
 
-Marc Langheinrich, marclang@cpan.org
+Marc Langheinrich, marclang@cs.washington.edu
 
 =head1 SEE ALSO
 
 L<LWP::Parallel::RobotUA>, L<LWP::Parallel::UserAgent>, L<LWP::RobotUA>
 
-=head1 COPYRIGHT
-
-Copyright 1997-2001 Marc Langheinrich.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =cut
 
